cofaTest: Calculates CoFA statistics for a random forest on the...

Description Usage Arguments

View source: R/cofaTest.R

Description

Calculates CoFA statistics for a random forest on the provided data and simulated the null hypothesis distribution by calculating CoFA statistics on data with the categorical variable shuffled

Usage

1
cofaTest(k = 10, data, xvars, yvar, cvar, ntree = 100, seed = NULL)

Arguments

k

number of iterations to simulate null hypothesis CoFA statistics

data

data.frame containing columns xvars, yvar, cvar

yvar

name of column containing the outcome variable

cvar

name of column containing the categorical variable of interest

ntree

number of trees per random forest

seed

a random seed

xvar

vector of other columns to use in fitting random forests


halleewong/cofa documentation built on Nov. 4, 2019, 1:26 p.m.