getAllFreqofLevel: Counts the appearances of all categories in a single tree

Description Usage Arguments Value

View source: R/cofaForest_helpers.R

Description

Counts the appearances of all categories in a single tree

Usage

1

Arguments

mat

a matrix returned by getMatix()

Value

An integer vector containing the number of splits involving each category


halleewong/cofa documentation built on Nov. 4, 2019, 1:26 p.m.