getCofa: Calculates the cofa statistic for a pair of levels

Description Usage Arguments Value

View source: R/cofaForest_helpers.R

Description

This helper function is used by makeCofaMat()

Usage

1
getCofa(i, j, mat)

Arguments

i

an integer

j

an integer

mat

a matrix of numeric values

Value

Calculated cofa statistic for level i and level j of the categorical variable of interest using the tree split matrix mat. The cofa statistic is the probability that levels i and \levelj split together at a node where the categorical variable of interest is used to split.


halleewong/cofa documentation built on Nov. 4, 2019, 1:26 p.m.