getCounts: Counts the number of times two categories split together...

Description Usage Arguments Value

View source: R/cofaForest_helpers.R

Description

This helper function is used by makeCofaMat() and cofaForest()

Usage

1
getCounts(i, j, mat)

Arguments

i

the index of a level

j

the index of a level

mat

a split matrix returned by getMatrix()

Value

A list containing two objects: together is the number of times level i and level j of the categorical variable of interest split in the same direction apart is the number of times level i and level j split apart.


halleewong/cofa documentation built on Nov. 4, 2019, 1:26 p.m.