makeCofaMat: Create a matrix of cofa statistics from the split matric of a...

Description Usage Arguments Value

View source: R/cofaForest_helpers.R

Description

Create a matrix of cofa statistics from the split matric of a single tree

Usage

1

Arguments

mat

a matrix or vector.

Value

A matrix where cell (i,j) contains the cofa statistic for level i and level j of the categorical variable of interest. The cofa statistic is the probability that levels i and j split together at a node where the categorical variable of interest is used to split.


halleewong/cofa documentation built on Nov. 4, 2019, 1:26 p.m.