Description Usage Arguments Value
Fits a Random Forest and calculated CoFA statistics for all pairs of categories.
1 2 | cofaForest(ntree = 100, cvar, yvar, xvars, data, control.cp = 0.001,
seed = 4, indices = NULL)
|
ntree |
integer number of trees to fit within the random forest |
cvar |
name of the |
yvar |
name of the column containing a binary outcome variable |
xvars |
vector of names of columns to use as predictors |
data |
a data.frame including columns |
indices |
a list of vectors containing the indices of rows to be used when fitting each tree. If |
A list of outputs including a matrix of CoFA statistics (freqMat), a matrix with the total number of times each pair of categories are used for splitting (totalMat), a list of rpart tree objects (tree) and a list of the indices used to fit each tree (indices).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.