Calculates CoFA statistics for a random forest on the provided data and simulated the null hypothesis distribution by calculating CoFA statistics on data with the categorical variable shuffled
1 |
k |
number of iterations to simulate null hypothesis CoFA statistics |
data |
data.frame containing columns |
yvar |
name of column containing the outcome variable |
cvar |
name of column containing the categorical variable of interest |
ntree |
number of trees per random forest |
seed |
a random seed |
xvar |
vector of other columns to use in fitting random forests |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.