Description Usage Arguments Value
View source: R/cofaForest_helpers.R
Counts the appearances of all categories in a single tree
1 | getAllFreqofLevel(mat)
|
mat |
a matrix returned by |
An integer vector containing the number of splits involving each category
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.