Description Usage Arguments Value
View source: R/cofaForest_helpers.R
This helper function is used by makeCofaMat()
1 | getCofa(i, j, mat)
|
i |
an integer |
j |
an integer |
mat |
a matrix of numeric values |
Calculated cofa statistic for level i and level j of the categorical variable of interest using the tree split matrix mat. The cofa statistic is the probability that levels i and \levelj split together at a node where the categorical variable of interest is used to split.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.