Description Usage Arguments Value
View source: R/cofaForest_helpers.R
This helper function is used by makeCofaMat() and cofaForest()
1 | getCounts(i, j, mat)
|
i |
the index of a level |
j |
the index of a level |
mat |
a split matrix returned by |
A list containing two objects:
together is the number of times level i and level j of the categorical variable of interest split in the same direction
apart is the number of times level i and level j split apart.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.