Description Usage Arguments Value
View source: R/cofaForest_helpers.R
Create a matrix of cofa statistics from the split matric of a single tree
1 | makeCofaMat(mat)
|
mat |
a matrix or vector. |
A matrix where cell (i,j) contains the cofa statistic for level i and level j of the categorical variable of interest. The cofa statistic is the probability that levels i and j split together at a node where the categorical variable of interest is used to split.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.